<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../ui/about.ui" line="165"/>
        <source>Supported image formats:</source>
        <translation>Formati immagine supportati:</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="6"/>
        <source>About Wally</source>
        <translation>Informazioni su Wally</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="94"/>
        <source>Details &gt;&gt;</source>
        <translation>Dettagli &gt;&gt;</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="47"/>
        <source>Compiled with:</source>
        <translation>Compilata con:</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="49"/>
        <source>EXIF library:</source>
        <translation>Libreria EXIF:</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="52"/>
        <source>present</source>
        <translation>presente</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="54"/>
        <source>not present</source>
        <translation>non presente</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="74"/>
        <source>Chinese (Simplified)</source>
        <translation>Cinese (Semplificato)</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="76"/>
        <source>Chinese (Traditional)</source>
        <translation>Cinese (Tradizionale)</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="78"/>
        <source>Polish</source>
        <translation>Polacco</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="80"/>
        <source>Catalan</source>
        <translation>Catalano</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="82"/>
        <source>Greek</source>
        <translation>Greco</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="84"/>
        <source>Korean</source>
        <translation>Coreano</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="86"/>
        <source>Hungarian</source>
        <translation>Ungherese</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="88"/>
        <source>Danish</source>
        <translation>Danese</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="90"/>
        <source>Swedish</source>
        <translation>Svedese</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="92"/>
        <source>Turkish</source>
        <translation>Turco</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="104"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="152"/>
        <source>Extension</source>
        <translation>Estensione</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="157"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="172"/>
        <source>Additional info:</source>
        <translation>Informazioni aggiuntive:</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="244"/>
        <source>Language</source>
        <translation>Lingua</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="249"/>
        <source>Translator</source>
        <translation>Traduttore</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="65"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;/head&gt;&lt;body&gt;&lt;font size=&quot;+1&quot;&gt;Qt4 desktop wallpaper changer&lt;br /&gt;Author: Antonio Di Monaco (a.k.a. &lt;i&gt;Sin(x) &apos;76&lt;/i&gt;)&lt;br /&gt;I&apos;d like to thank Vincent Willem van Gogh for the logo :)&lt;br /&gt;&lt;br /&gt;Web site: &lt;a href=&quot;http://www.becrux.com&quot;&gt;http://www.becrux.com&lt;/a&gt;&lt;br /&gt;You can contact me at &lt;a href=&quot;mailto:tony@becrux.com?subject=About Wally&quot;&gt;tony@becrux.com&lt;/font&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;/head&gt;&lt;body&gt;&lt;font size=&quot;+1&quot;&gt;Cambiasfondo Qt4&lt;br /&gt;Autore: Antonio Di Monaco (a.k.a. &lt;i&gt;Sin(x) &apos;76&lt;/i&gt;)&lt;br /&gt;Desidero ringraziare Vincent Willem van Gogh per il logo :)&lt;br /&gt;&lt;br /&gt;Sito web: &lt;a href=&quot;http://www.becrux.com&quot;&gt;http://www.becrux.com&lt;/a&gt;&lt;br /&gt;Puoi contattarmi scrivendo a &lt;a href=&quot;mailto:tony@becrux.com?subject=About Wally&quot;&gt;tony@becrux.com&lt;/font&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="60"/>
        <source>Italian</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="58"/>
        <source>English</source>
        <translation>Inglese</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="62"/>
        <source>Russian</source>
        <translation>Russo</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="64"/>
        <source>Spanish</source>
        <translation>Spagnolo</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="66"/>
        <source>Portuguese (Brazil)</source>
        <translation>Portoghese (Brasile)</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="68"/>
        <source>German</source>
        <translation>Tedesco</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="70"/>
        <source>French</source>
        <translation>Francese</translation>
    </message>
    <message>
        <location filename="../../src/about.cpp" line="72"/>
        <source>Czech</source>
        <translation>Ceco</translation>
    </message>
    <message>
        <location filename="../../ui/about.ui" line="257"/>
        <source>Translations:</source>
        <translation>Traduzioni:</translation>
    </message>
</context>
<context>
    <name>Bing::DialogWidget</name>
    <message>
        <location filename="../../src/bing.cpp" line="304"/>
        <source>All of these words</source>
        <translation>Tutte le parole</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="305"/>
        <source>Any of these words</source>
        <translation>Una di queste parole</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="308"/>
        <source>Search for:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="314"/>
        <source>Strict</source>
        <translation>Elevato</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="315"/>
        <source>Moderate</source>
        <translation>Moderato</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="316"/>
        <source>Off</source>
        <translation>Disattivato</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="319"/>
        <source>Adult filter:</source>
        <translation>Filtro adulti:</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="342"/>
        <source>Bing item</source>
        <translation>Oggetto Bing</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="343"/>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>Il contenuto non filtrato potrà mostrare immagini offensive o sessualmente esplicite</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="354"/>
        <source>Edit Bing item</source>
        <translation>Edita oggetto Bing</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="361"/>
        <source>Add Bing item</source>
        <translation>Aggiungi oggetto Bing</translation>
    </message>
</context>
<context>
    <name>Bing::Item</name>
    <message>
        <location filename="../../src/bing.cpp" line="56"/>
        <source>Tags:</source>
        <translation>Tag:</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="58"/>
        <source>and</source>
        <translation>e</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="58"/>
        <source>or</source>
        <translation>o</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="59"/>
        <source>Adult filter:</source>
        <translation>Filtro adulti:</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="64"/>
        <source>Off</source>
        <translation>Disattivato</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="68"/>
        <source>Moderate</source>
        <translation>Moderato</translation>
    </message>
    <message>
        <location filename="../../src/bing.cpp" line="73"/>
        <source>Strict</source>
        <translation>Elevato</translation>
    </message>
</context>
<context>
    <name>Buzznet::DialogWidget</name>
    <message>
        <location filename="../../src/buzznet.cpp" line="225"/>
        <source>Search for:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <location filename="../../src/buzznet.cpp" line="248"/>
        <source>Edit Buzznet item</source>
        <translation>Edita oggetto Buzznet</translation>
    </message>
    <message>
        <location filename="../../src/buzznet.cpp" line="253"/>
        <source>Add Buzznet item</source>
        <translation>Aggiungi oggetto Buzznet</translation>
    </message>
</context>
<context>
    <name>Buzznet::Item</name>
    <message>
        <location filename="../../src/buzznet.cpp" line="42"/>
        <source>Tag:</source>
        <translation>Tag:</translation>
    </message>
</context>
<context>
    <name>DeviantArt::DialogWidget</name>
    <message>
        <location filename="../../src/deviantart.cpp" line="247"/>
        <source>Search for:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="252"/>
        <source>Strict</source>
        <translation>Elevato</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="253"/>
        <source>Off</source>
        <translation>Disattivato</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="256"/>
        <source>Adult filter:</source>
        <translation>Filtro adulti:</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="277"/>
        <source>deviantART item</source>
        <translation>Oggetto deviantART</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="278"/>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>Il contenuto non filtrato potrà mostrare immagini offensive o sessualmente esplicite</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="289"/>
        <source>Edit deviantART item</source>
        <translation>Edita oggetto deviantART</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="295"/>
        <source>Add deviantART item</source>
        <translation>Aggiungi oggetto deviantART</translation>
    </message>
</context>
<context>
    <name>DeviantArt::Item</name>
    <message>
        <location filename="../../src/deviantart.cpp" line="43"/>
        <source>Tag:</source>
        <translation>Tag:</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="44"/>
        <source>Adult filter:</source>
        <translation>Filtro adulti:</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="49"/>
        <source>Off</source>
        <translation>Disattivato</translation>
    </message>
    <message>
        <location filename="../../src/deviantart.cpp" line="54"/>
        <source>Strict</source>
        <translation>Elevato</translation>
    </message>
</context>
<context>
    <name>Exif::InfoDialog</name>
    <message>
        <location filename="../../src/exif.cpp" line="260"/>
        <source>EXIF information</source>
        <translation>Informazioni EXIF</translation>
    </message>
    <message>
        <location filename="../../src/exif.cpp" line="274"/>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
    <message>
        <location filename="../../src/exif.cpp" line="275"/>
        <source>Value</source>
        <translation>Valore</translation>
    </message>
    <message>
        <location filename="../../src/exif.cpp" line="298"/>
        <source>No EXIF information available</source>
        <translation>Nessuna informazione EXIF disponibile</translation>
    </message>
</context>
<context>
    <name>Files::Core</name>
    <message>
        <location filename="../../src/files.cpp" line="145"/>
        <source>Loading folder...</source>
        <translation>Carico cartella...</translation>
    </message>
</context>
<context>
    <name>Files::LabelPreview</name>
    <message>
        <location filename="../../src/files.cpp" line="261"/>
        <source>No preview available</source>
        <translation>Anteprima non disponibile</translation>
    </message>
</context>
<context>
    <name>Files::SettingsWidget</name>
    <message>
        <location filename="../../src/files.cpp" line="281"/>
        <location filename="../../src/files.cpp" line="334"/>
        <source>Select a photo</source>
        <translation>Seleziona una foto</translation>
    </message>
    <message>
        <location filename="../../src/files.cpp" line="297"/>
        <location filename="../../src/files.cpp" line="302"/>
        <source>Select a folder</source>
        <translation>Seleziona una cartella</translation>
    </message>
</context>
<context>
    <name>FilesSettingsWidget</name>
    <message>
        <location filename="../../ui/files.ui" line="15"/>
        <source>Photos</source>
        <translation>Foto</translation>
    </message>
    <message>
        <location filename="../../ui/files.ui" line="39"/>
        <source>Add a photo</source>
        <translation>Aggiungi una foto</translation>
    </message>
    <message>
        <location filename="../../ui/files.ui" line="59"/>
        <source>Add photos in folder</source>
        <translation>Aggiungi foto in cartella</translation>
    </message>
    <message>
        <location filename="../../ui/files.ui" line="82"/>
        <source>Delete photo</source>
        <translation>Elimina foto</translation>
    </message>
    <message>
        <location filename="../../ui/files.ui" line="118"/>
        <source>Move photo up</source>
        <translation>Sposta foto su</translation>
    </message>
    <message>
        <location filename="../../ui/files.ui" line="141"/>
        <source>Move photo down</source>
        <translation>Sposta foto giù</translation>
    </message>
</context>
<context>
    <name>Flickr::DialogWidget</name>
    <message>
        <location filename="../../src/flickr.cpp" line="395"/>
        <source>All of these words</source>
        <translation>Tutte le parole</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="396"/>
        <source>Any of these words</source>
        <translation>Una di queste parole</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="400"/>
        <source>Search for:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="404"/>
        <source>Full text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="405"/>
        <source>Tags only</source>
        <translation>Solo tag</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="413"/>
        <source>Largest</source>
        <translation>La più larga</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="414"/>
        <source>Original</source>
        <translation>Originale</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="415"/>
        <source>Large</source>
        <translation>Larga</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="416"/>
        <source>Medium</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="417"/>
        <source>Small</source>
        <translation>Piccola</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="418"/>
        <source>Thumbnail</source>
        <translation>Miniatura</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="419"/>
        <source>Square</source>
        <translation>Quadrata</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="420"/>
        <source>Smallest</source>
        <translation>La piu piccola</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="426"/>
        <source>Relevance</source>
        <translation>Rilevanza</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="434"/>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="436"/>
        <source>Order:</source>
        <translation>Ordine:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="478"/>
        <source>Edit Flickr item</source>
        <translation>Edita oggetto Flickr</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="496"/>
        <source>Add Flickr item</source>
        <translation>Aggiungi oggetto Flickr</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="425"/>
        <source>Interestingness desc</source>
        <translation>Interesse disc</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="427"/>
        <source>Date posted desc</source>
        <translation>Data pubblicazione disc</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="428"/>
        <source>Date taken desc</source>
        <translation>Data scatto disc</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="429"/>
        <source>Interestingness asc</source>
        <translation>Interesse asc</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="430"/>
        <source>Date posted asc</source>
        <translation>Data pubblicazione asc</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="431"/>
        <source>Date taken asc</source>
        <translation>Data scatto asc</translation>
    </message>
</context>
<context>
    <name>Flickr::Item</name>
    <message>
        <location filename="../../src/flickr.cpp" line="58"/>
        <source>Text:</source>
        <translation>Testo:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="60"/>
        <source>Tags:</source>
        <translation>Tag:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="61"/>
        <source>and</source>
        <translation>e</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="62"/>
        <source>or</source>
        <translation>o</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="66"/>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="69"/>
        <source>Largest</source>
        <translation>La più larga</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="70"/>
        <source>Original</source>
        <translation>Originale</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="71"/>
        <source>Large</source>
        <translation>Larga</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="72"/>
        <source>Medium</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="73"/>
        <source>Small</source>
        <translation>Piccola</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="74"/>
        <source>Thumbnail</source>
        <translation>Miniatura</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="75"/>
        <source>Square</source>
        <translation>Quadrata</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="76"/>
        <source>Smallest</source>
        <translation>La piu piccola</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="79"/>
        <source>Order:</source>
        <translation>Ordine:</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="83"/>
        <source>Relevance</source>
        <translation>Rilevanza</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="82"/>
        <source>Interestingness desc</source>
        <translation>Interesse disc</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="84"/>
        <source>Date posted desc</source>
        <translation>Data pubblicazione disc</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="85"/>
        <source>Date taken desc</source>
        <translation>Data scatto disc</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="86"/>
        <source>Interestingness asc</source>
        <translation>Interesse asc</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="87"/>
        <source>Date posted asc</source>
        <translation>Data pubblicazione asc</translation>
    </message>
    <message>
        <location filename="../../src/flickr.cpp" line="88"/>
        <source>Date taken asc</source>
        <translation>Data scatto asc</translation>
    </message>
</context>
<context>
    <name>Folders::DialogWidget</name>
    <message>
        <location filename="../../src/folders.cpp" line="463"/>
        <source>Include subfolders</source>
        <translation>Includi sottocartelle</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="534"/>
        <location filename="../../src/folders.cpp" line="539"/>
        <source>Select a folder</source>
        <translation>Seleziona una cartella</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="588"/>
        <source>Edit folder</source>
        <translation>Edita cartella</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="614"/>
        <source>Add folder</source>
        <translation>Aggiungi cartella</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="447"/>
        <location filename="../../src/folders.cpp" line="456"/>
        <source>Local</source>
        <translation>Locale</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="448"/>
        <location filename="../../src/folders.cpp" line="479"/>
        <source>Remote</source>
        <translation>Remota</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="469"/>
        <source>Folder:</source>
        <translation>Cartella:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="488"/>
        <source>Passive</source>
        <translation>Passiva</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="489"/>
        <source>Active</source>
        <translation>Attiva</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="501"/>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="503"/>
        <source>Port:</source>
        <translation>Porta:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="505"/>
        <source>Transfer mode:</source>
        <translation>Modalità:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="507"/>
        <source>Username:</source>
        <translation>Nome utente:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="509"/>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="511"/>
        <source>Path:</source>
        <translation>Percorso:</translation>
    </message>
</context>
<context>
    <name>Folders::LocalItem</name>
    <message>
        <location filename="../../src/folders.cpp" line="149"/>
        <source>(with subfolders)</source>
        <translation>(con sottocartelle)</translation>
    </message>
</context>
<context>
    <name>Folders::RemoteItem</name>
    <message>
        <location filename="../../src/folders.cpp" line="253"/>
        <source>Transfer mode:</source>
        <translation>Modalità:</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="254"/>
        <source>passive</source>
        <translation>passiva</translation>
    </message>
    <message>
        <location filename="../../src/folders.cpp" line="254"/>
        <source>active</source>
        <translation>attiva</translation>
    </message>
</context>
<context>
    <name>FoldersSettingsWidget</name>
    <message>
        <location filename="../../ui/folders.ui" line="15"/>
        <source>Folders</source>
        <translation>Cartelle</translation>
    </message>
    <message>
        <location filename="../../ui/folders.ui" line="26"/>
        <source>Add a folder</source>
        <translation>Aggiungi una cartella</translation>
    </message>
    <message>
        <location filename="../../ui/folders.ui" line="49"/>
        <source>Delete folder</source>
        <translation>Elimina cartella</translation>
    </message>
</context>
<context>
    <name>Google::DialogWidget</name>
    <message>
        <location filename="../../src/google.cpp" line="347"/>
        <source>Search for:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="352"/>
        <source>Strict</source>
        <translation>Elevato</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="353"/>
        <source>Moderate</source>
        <translation>Moderato</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="354"/>
        <source>Off</source>
        <translation>Disattivato</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="357"/>
        <source>Adult filter:</source>
        <translation>Filtro adulti:</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="378"/>
        <source>Google item</source>
        <translation>Oggetto Google</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="379"/>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="390"/>
        <source>Edit Google item</source>
        <translation>Edita oggetto Google</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="396"/>
        <source>Add Google item</source>
        <translation>Aggiungi oggetto Google</translation>
    </message>
</context>
<context>
    <name>Google::Item</name>
    <message>
        <location filename="../../src/google.cpp" line="55"/>
        <source>Text:</source>
        <translation>Testo:</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="56"/>
        <source>Adult filter:</source>
        <translation>Filtro adulti:</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="61"/>
        <source>Off</source>
        <translation>Disattivato</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="65"/>
        <source>Moderate</source>
        <translation>Moderato</translation>
    </message>
    <message>
        <location filename="../../src/google.cpp" line="70"/>
        <source>Strict</source>
        <translation>Elevato</translation>
    </message>
</context>
<context>
    <name>Gui::ColorButton</name>
    <message>
        <location filename="../../src/gui.cpp" line="132"/>
        <location filename="../../src/gui.cpp" line="140"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
</context>
<context>
    <name>History::Dialog</name>
    <message>
        <location filename="../../src/history.cpp" line="364"/>
        <source>Right-click on items to show options</source>
        <translation>Click con il destro sulle voci per visualizzare le opzioni</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="395"/>
        <location filename="../../src/history.cpp" line="596"/>
        <location filename="../../src/history.cpp" line="613"/>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="440"/>
        <source>Please wait...</source>
        <translation>Attendere prego...</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="441"/>
        <source>Downloading photo...</source>
        <translation>Scarica foto...</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="442"/>
        <source>Abort</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="454"/>
        <location filename="../../src/history.cpp" line="458"/>
        <source>Save photo</source>
        <translation>Salva foto</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="456"/>
        <location filename="../../src/history.cpp" line="461"/>
        <source>Images (*.png *.xpm *.jpg)</source>
        <translation>Immagini (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="596"/>
        <source>Photo has been saved</source>
        <translation>La foto é stata salvata</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="613"/>
        <source>There was an error during download</source>
        <translation>Errore durante il download</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="663"/>
        <source>View photo...</source>
        <translation>Visualizza foto...</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="667"/>
        <source>Get EXIF info...</source>
        <translation>Mostra informazioni EXIF...</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="671"/>
        <source>Save photo...</source>
        <translation>Salva foto...</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="675"/>
        <source>Set as background</source>
        <translation>Imposta come sfondo</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="679"/>
        <source>Explore image source</source>
        <translation>Esplora sorgente</translation>
    </message>
</context>
<context>
    <name>History::EngineQueryModel</name>
    <message>
        <location filename="../../src/history.cpp" line="70"/>
        <source>All</source>
        <translation>Tutti</translation>
    </message>
</context>
<context>
    <name>History::PhotosQueryModel</name>
    <message>
        <location filename="../../src/history.cpp" line="250"/>
        <source>Image size:</source>
        <translation>Dimensioni immagine:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="252"/>
        <source>Engine:</source>
        <translation>Modulo:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="253"/>
        <source>EXIF:</source>
        <translation>EXIF:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="253"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="253"/>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="238"/>
        <source>(no title)</source>
        <translation>(nessun titolo)</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="240"/>
        <source>by:</source>
        <translation>da:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="241"/>
        <source>(no author)</source>
        <translation>(nessun autore)</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="245"/>
        <source>Location:</source>
        <translation>Luogo:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="246"/>
        <source>unknown</source>
        <translation>sconosciuto</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="248"/>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <location filename="../../src/history.cpp" line="243"/>
        <source>Date:</source>
        <translation>Data:</translation>
    </message>
</context>
<context>
    <name>History::TagsQueryModel</name>
    <message>
        <location filename="../../src/history.cpp" line="99"/>
        <source>All</source>
        <translation>Tutti</translation>
    </message>
</context>
<context>
    <name>HttpEngine::SettingsWidget</name>
    <message>
        <location filename="../../src/httpengine.cpp" line="656"/>
        <location filename="../../src/httpengine.cpp" line="661"/>
        <source>Select a folder</source>
        <translation>Seleziona una cartella</translation>
    </message>
</context>
<context>
    <name>HttpSettingsWidget</name>
    <message>
        <location filename="../../ui/http.ui" line="12"/>
        <source>Photo sets</source>
        <translation>Set foto</translation>
    </message>
    <message>
        <location filename="../../ui/http.ui" line="97"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="../../ui/http.ui" line="103"/>
        <source>Save photos</source>
        <translation>Salva foto</translation>
    </message>
    <message>
        <location filename="../../ui/http.ui" line="20"/>
        <source>Add a photo set</source>
        <translation>Aggiungi un set foto</translation>
    </message>
    <message>
        <location filename="../../ui/http.ui" line="43"/>
        <source>Delete photo set</source>
        <translation>Elimina set foto</translation>
    </message>
</context>
<context>
    <name>Ipernity::DialogWidget</name>
    <message>
        <location filename="../../src/ipernity.cpp" line="284"/>
        <source>All of these words</source>
        <translation>Tutte le parole</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="285"/>
        <source>Any of these words</source>
        <translation>Una di queste parole</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="288"/>
        <source>Search for:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="292"/>
        <source>Full text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="293"/>
        <source>Tags only</source>
        <translation>Solo tag</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="309"/>
        <source>Ipernity item</source>
        <translation>Oggetto Ipernity</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="310"/>
        <source>It can show offending or sexual explicit photos</source>
        <translation>Potrà mostrare immagini offensive o sessualmente esplicite</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="331"/>
        <source>Edit Ipernity item</source>
        <translation>Edita oggetto Ipernity</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="347"/>
        <source>Add Ipernity item</source>
        <translation>Aggiungi oggetto Ipernity</translation>
    </message>
</context>
<context>
    <name>Ipernity::Item</name>
    <message>
        <location filename="../../src/ipernity.cpp" line="57"/>
        <source>Text:</source>
        <translation>Testo:</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="58"/>
        <location filename="../../src/ipernity.cpp" line="63"/>
        <source>and</source>
        <translation>e</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="59"/>
        <location filename="../../src/ipernity.cpp" line="64"/>
        <source>or</source>
        <translation>o</translation>
    </message>
    <message>
        <location filename="../../src/ipernity.cpp" line="66"/>
        <source>Tags:</source>
        <translation>Tag:</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../../src/main.cpp" line="65"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="68"/>
        <source>is already running</source>
        <translation>è già in esecuzione</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="77"/>
        <source>Disclaimer</source>
        <translation>Esclusione di responsabilità</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="78"/>
        <source>&lt;b&gt;The Author takes no responsibility over the content that Wally downloads from photo sharing web sites.&lt;br&gt;The Author is in no way responsible for any such content.&lt;/b&gt;&lt;br&gt;&lt;br&gt;If this is a problem for you, please use only local engines like &quot;Files&quot; or local &quot;Folders&quot;.&lt;br&gt;Otherwise, please select &lt;b&gt;&quot;No&quot;&lt;/b&gt; to exit Wally, or use it &lt;b&gt;at your own risk.&lt;/b&gt;&lt;br&gt;&lt;br&gt;(If you proceed, this message will appear only once)&lt;br&gt;&lt;br&gt;Do you accept the above condition?</source>
        <translation>&lt;b&gt;L&apos;Autore non si assume alcuna responsabilità riguardo il contenuto delle foto che Wally scarica dai siti di photo sharing.&lt;br&gt;L&apos;Autore non è in alcun modo responsabile per tali contenuti.&lt;/b&gt;&lt;br&gt;&lt;br&gt;Laddove ciò fosse un problema, si utilizzino soltanto motori locali come &quot;Foto&quot; oppure &quot;Cartelle&quot;.&lt;br&gt;Altrimenti, scegliere &lt;b&gt;&quot;No&quot;&lt;/b&gt; per terminare Wally, oppure continuare &lt;b&gt;a proprio rischio.&lt;/b&gt;&lt;br&gt;&lt;br&gt;(Se si procede, questo messaggio verrà visualizzato una volta soltanto)&lt;br&gt;&lt;br&gt;Si accetta tale condizione?</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="66"/>
        <source>Another instance of</source>
        <translation>Una istanza di</translation>
    </message>
</context>
<context>
    <name>Map::View</name>
    <message>
        <location filename="../../src/mapviewer.cpp" line="387"/>
        <source>Drag to select. Right-click to zoom</source>
        <translation>Trascina per selezionare. Click con il destro per ingrandire</translation>
    </message>
    <message>
        <location filename="../../src/mapviewer.cpp" line="395"/>
        <source>Zoom %1x</source>
        <translation>Zoom %1x</translation>
    </message>
</context>
<context>
    <name>Map::Viewer</name>
    <message>
        <location filename="../../src/mapviewer.cpp" line="434"/>
        <source>Map viewer</source>
        <translation>Visualizzatore mappa</translation>
    </message>
</context>
<context>
    <name>Panoramio::DialogWidget</name>
    <message>
        <location filename="../../src/panoramio.cpp" line="322"/>
        <source>Select on map</source>
        <translation>Seleziona su mappa</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="328"/>
        <source>Longitude (min):</source>
        <translation>Longitudine (min):</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="330"/>
        <source>Longitude (max):</source>
        <translation>Longitudine (max):</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="332"/>
        <source>Latitude (min):</source>
        <translation>Latitudine (min):</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="334"/>
        <source>Latitude (max):</source>
        <translation>Latitudine (max):</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="352"/>
        <source>Popularity</source>
        <translation>Popolarità</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="353"/>
        <source>Upload date</source>
        <translation>Data pubblicazione</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="358"/>
        <source>Original</source>
        <translation>Originale</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="359"/>
        <source>Medium</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="360"/>
        <source>Small</source>
        <translation>Piccola</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="361"/>
        <source>Thumbnail</source>
        <translation>Miniatura</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="362"/>
        <source>Square</source>
        <translation>Quadrata</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="363"/>
        <source>Mini square</source>
        <translation>Quadrata mini</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="366"/>
        <source>Order:</source>
        <translation>Ordine:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="367"/>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="414"/>
        <source>Edit Panoramio item</source>
        <translation>Edita oggetto Panoramio</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="427"/>
        <source>Add Panoramio item</source>
        <translation>Aggiungi oggetto Panoramio</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="435"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="435"/>
        <source>Coordinates must be different</source>
        <translation>Le coordinate devono essere differenti</translation>
    </message>
</context>
<context>
    <name>Panoramio::Item</name>
    <message>
        <location filename="../../src/panoramio.cpp" line="284"/>
        <source>Original</source>
        <translation>Originale</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="285"/>
        <source>Medium</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="286"/>
        <source>Small</source>
        <translation>Piccola</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="287"/>
        <source>Thumbnail</source>
        <translation>Miniatura</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="288"/>
        <source>Square</source>
        <translation>Quadrata</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="289"/>
        <source>Mini square</source>
        <translation>Quadrata mini</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="294"/>
        <source>Popularity</source>
        <translation>Popolarità</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="295"/>
        <source>Upload date</source>
        <translation>Data pubblicazione</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="298"/>
        <source>Longitude:</source>
        <translation>Longitudine:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="301"/>
        <source>Latitude:</source>
        <translation>Latitudine:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="304"/>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="305"/>
        <source>Order:</source>
        <translation>Ordine:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="185"/>
        <source>lat:</source>
        <translation>lat:</translation>
    </message>
    <message>
        <location filename="../../src/panoramio.cpp" line="186"/>
        <source>lon:</source>
        <translation>lon:</translation>
    </message>
</context>
<context>
    <name>Photobucket::DialogWidget</name>
    <message>
        <location filename="../../src/photobucket.cpp" line="279"/>
        <source>Search for:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="293"/>
        <source>Photobucket item</source>
        <translation>Oggetto Photobucket</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="294"/>
        <source>It can show offending or sexual explicit photos</source>
        <translation>Potrà mostrare immagini offensive o sessualmente esplicite</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="311"/>
        <source>Edit Photobucket item</source>
        <translation>Edita oggetto Photobucket</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="317"/>
        <source>Add Photobucket item</source>
        <translation>Aggiungi oggetto Photobucket</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="275"/>
        <source>All of these words</source>
        <translation>Tutte le parole</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="276"/>
        <source>Any of these words</source>
        <translation>Una di queste parole</translation>
    </message>
</context>
<context>
    <name>Photobucket::Item</name>
    <message>
        <location filename="../../src/photobucket.cpp" line="81"/>
        <source>Text:</source>
        <translation>Testo:</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="82"/>
        <source>and</source>
        <translation>e</translation>
    </message>
    <message>
        <location filename="../../src/photobucket.cpp" line="83"/>
        <source>or</source>
        <translation>o</translation>
    </message>
</context>
<context>
    <name>Picasa::DialogWidget</name>
    <message>
        <location filename="../../src/picasa.cpp" line="255"/>
        <source>Search for:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <location filename="../../src/picasa.cpp" line="278"/>
        <source>Edit Picasa item</source>
        <translation>Edita oggetto Picasa</translation>
    </message>
    <message>
        <location filename="../../src/picasa.cpp" line="283"/>
        <source>Add Picasa item</source>
        <translation>Aggiungi oggetto Picasa</translation>
    </message>
</context>
<context>
    <name>Picasa::Item</name>
    <message>
        <location filename="../../src/picasa.cpp" line="47"/>
        <source>Text:</source>
        <translation>Testo:</translation>
    </message>
</context>
<context>
    <name>Pikeo::DialogWidget</name>
    <message>
        <location filename="../../src/pikeo.cpp" line="268"/>
        <source>Search for:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="273"/>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="274"/>
        <source>Most viewed</source>
        <translation>La più visualizzata</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="275"/>
        <source>Upload date</source>
        <translation>Data pubblicazione</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="276"/>
        <source>Date taken</source>
        <translation>Data scatto</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="277"/>
        <source>Group add date</source>
        <translation>Data aggiunta gruppo</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="278"/>
        <source>Comment date</source>
        <translation>Data commento</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="282"/>
        <source>Ascending</source>
        <translation>Ascendente</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="284"/>
        <source>Order:</source>
        <translation>Ordine:</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="315"/>
        <source>Edit Pikeo item</source>
        <translation>Edita oggetto Pikeo</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="322"/>
        <source>Add Pikeo item</source>
        <translation>Aggiungi oggetto Pikeo</translation>
    </message>
</context>
<context>
    <name>Pikeo::Item</name>
    <message>
        <location filename="../../src/pikeo.cpp" line="56"/>
        <source>Tags:</source>
        <translation>Tag:</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="57"/>
        <source>Order:</source>
        <translation>Ordine:</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="61"/>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="62"/>
        <source>Most viewed</source>
        <translation>La più visualizzata</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="63"/>
        <source>Upload date</source>
        <translation>Data pubblicazione</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="64"/>
        <source>Date taken</source>
        <translation>Data scatto</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="65"/>
        <source>Group add date</source>
        <translation>Data aggiunta gruppo</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="66"/>
        <source>Comment date</source>
        <translation>Data commento</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="69"/>
        <source>ascending</source>
        <translation>ascendente</translation>
    </message>
    <message>
        <location filename="../../src/pikeo.cpp" line="69"/>
        <source>descending</source>
        <translation>discendente</translation>
    </message>
</context>
<context>
    <name>PositionModel</name>
    <message>
        <location filename="../../src/settings.cpp" line="133"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="136"/>
        <source>Picture smaller than screen on the left, greater than screen on the right</source>
        <translation>Immagine più piccola dello schermo a sinistra, più grande a destra</translation>
    </message>
</context>
<context>
    <name>QColorDialog</name>
    <message>
        <location filename="../../src/settings.cpp" line="184"/>
        <source>Hu&amp;e:</source>
        <translation>&amp;Tonalità:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="185"/>
        <source>&amp;Sat:</source>
        <translation>&amp;Saturazione:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="186"/>
        <source>&amp;Val:</source>
        <translation>&amp;Valore:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="187"/>
        <source>&amp;Red:</source>
        <translation>&amp;Rosso:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="188"/>
        <source>&amp;Green:</source>
        <translation>V&amp;erde:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="189"/>
        <source>Bl&amp;ue:</source>
        <translation>Bl&amp;ue:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="190"/>
        <source>Select Color</source>
        <translation>Colore</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="191"/>
        <source>&amp;Basic colors</source>
        <translation>Colori di &amp;base</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="192"/>
        <source>&amp;Custom colors</source>
        <translation>Colori &amp;personalizzati</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="193"/>
        <source>&amp;Add to Custom Colors</source>
        <translation>&amp;Aggiungi ai colori personalizzati</translation>
    </message>
</context>
<context>
    <name>QDialogButtonBox</name>
    <message>
        <location filename="../../src/settings.cpp" line="176"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="177"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="178"/>
        <source>Reset</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="179"/>
        <source>&amp;Yes</source>
        <translation>&amp;Sì</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="180"/>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="181"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="182"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
</context>
<context>
    <name>QFileDialog</name>
    <message>
        <location filename="../../src/settings.cpp" line="195"/>
        <source>Directories</source>
        <translation>Cartelle</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="196"/>
        <source>&amp;Open</source>
        <translation>&amp;Apri</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="197"/>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="198"/>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="199"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 esiste già. Sostituirlo?</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="200"/>
        <source>%1
File not found.
Please verify the correct file name was given.</source>
        <translation>%1 non trovato. Verificare che il nome del file sia corretto.</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="201"/>
        <source>My Computer</source>
        <translation>Risorse del computer</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="202"/>
        <source>&amp;Rename</source>
        <translation>&amp;Rinomina</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="203"/>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="204"/>
        <source>Show &amp;hidden files</source>
        <translation>Mostra &amp;file nascosti</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="205"/>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="206"/>
        <source>Parent Directory</source>
        <translation>Livello superiore</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="207"/>
        <source>List View</source>
        <translation>Elenco</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="208"/>
        <source>Detail View</source>
        <translation>Dettagli</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="209"/>
        <source>Files of type:</source>
        <translation>Tipo file:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="210"/>
        <source>Directory:</source>
        <translation>Cartella:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="211"/>
        <source>%1
Directory not found.
Please verify the correct directory name was given.</source>
        <translation>%1 non trovata. Verificare che il nome della cartella sia corretto.</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="212"/>
        <source>&apos;%1&apos; is write protected.
Do you want to delete it anyway?</source>
        <translation>%1 è protetta da scrittura. Cancellarla ugualmente?</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="213"/>
        <source>Are sure you want to delete &apos;%1&apos;?</source>
        <translation>Sicuro di voler cancellare %1?</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="214"/>
        <source>Could not delete directory.</source>
        <translation>Non è possibile cancellare la cartella.</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="215"/>
        <source>Recent Places</source>
        <translation>Documenti recenti</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="216"/>
        <source>Save As</source>
        <translation>Salva come</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="217"/>
        <source>Drive</source>
        <translation>Disco</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="218"/>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="219"/>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="220"/>
        <source>Find Directory</source>
        <translation>Trova cartella</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="221"/>
        <source>Show</source>
        <translation>Visualizza </translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="222"/>
        <source>Forward</source>
        <translation>Avanti</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="223"/>
        <source>New Folder</source>
        <translation>Nuova cartella</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="224"/>
        <source>&amp;New Folder</source>
        <translation>&amp;Nuova cartella</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="225"/>
        <source>&amp;Choose</source>
        <translation>S&amp;cegli</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="226"/>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="227"/>
        <source>File &amp;name:</source>
        <translation>No&amp;me file:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="228"/>
        <source>Look in:</source>
        <translation>Cerca in:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="229"/>
        <source>Create New Folder</source>
        <translation>Crea nuova cartella</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/utils.cpp" line="76"/>
        <source>All image files</source>
        <translation>Tutte le immagini</translation>
    </message>
    <message>
        <location filename="../../src/utils.cpp" line="80"/>
        <source>files</source>
        <translation>file</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="31"/>
        <source>Centered</source>
        <translation>Centrata</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="34"/>
        <source>Tiled</source>
        <translation>A mattonella</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="37"/>
        <source>Center Tiled</source>
        <translation>A mattonella centrata</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="40"/>
        <source>Centered Maxpect</source>
        <translation>Centrata e scalata corretta</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="43"/>
        <source>Tiled Maxpect</source>
        <translation>A mattonella e scalata corretta</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="46"/>
        <source>Scaled</source>
        <translation>Scalata</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="49"/>
        <source>Centered Auto Fit</source>
        <translation>Centrata e ridimensionata</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="52"/>
        <source>Scale &amp; Crop</source>
        <translation>Scalata e tagliata</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="55"/>
        <source>Symmetrical Tiled</source>
        <translation>A mattonella simmetrica</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="58"/>
        <source>Mirrored Tiled</source>
        <translation>A mattonella riflessa</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="61"/>
        <source>Symmetrical Mirrored Tiled</source>
        <translation>A mattonella riflessa simmetrica</translation>
    </message>
</context>
<context>
    <name>QProgressDialog</name>
    <message>
        <location filename="../../src/history.cpp" line="340"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../../src/settings.cpp" line="243"/>
        <source>kBytes</source>
        <translation>kByte</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="244"/>
        <source>MBytes</source>
        <translation>MByte</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="245"/>
        <source>GBytes</source>
        <translation>GByte</translation>
    </message>
    <message numerus="yes">
        <location filename="../../src/settings.cpp" line="248"/>
        <source>day(s)</source>
        <translation>
            <numerusform>giorno</numerusform>
            <numerusform>giorni</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../src/settings.cpp" line="249"/>
        <source>month(s)</source>
        <translation>
            <numerusform>mese</numerusform>
            <numerusform>mesi</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../src/settings.cpp" line="299"/>
        <location filename="../../src/settings.cpp" line="524"/>
        <source>second(s)</source>
        <translation>
            <numerusform>secondo</numerusform>
            <numerusform>secondi</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../src/settings.cpp" line="300"/>
        <location filename="../../src/settings.cpp" line="525"/>
        <source>minute(s)</source>
        <translation>
            <numerusform>minuto</numerusform>
            <numerusform>minuti</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../src/settings.cpp" line="301"/>
        <location filename="../../src/settings.cpp" line="526"/>
        <source>hour(s)</source>
        <translation>
            <numerusform>ora</numerusform>
            <numerusform>ore</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="453"/>
        <source>Set position</source>
        <translation>Imposta posizione</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="599"/>
        <source>Clear history</source>
        <translation>Cancella cronologia</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="599"/>
        <source>Are you sure?</source>
        <translation>Sei sicuro?</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="168"/>
        <location filename="../../src/settings.cpp" line="173"/>
        <location filename="../../src/settings.cpp" line="514"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="34"/>
        <source>General options</source>
        <translation>Opzioni generali</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="42"/>
        <source>Interval:</source>
        <translation>Intervallo:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="69"/>
        <source>Border:</source>
        <translation>Bordo:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="86"/>
        <location filename="../../ui/settings.ui" line="237"/>
        <source>Position:</source>
        <translation>Posizione:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="144"/>
        <source>Main</source>
        <translation>Generali</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="153"/>
        <source>Choose in random order</source>
        <translation>Scegli in ordine casuale</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="160"/>
        <source>Switch background on play</source>
        <translation>Cambia sfondo al play</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="167"/>
        <source>Play automatically on application start</source>
        <translation>Esegui play automaticamente all&apos;avvio</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="174"/>
        <source>Disable splash screen</source>
        <translation>Disabilita splash screen</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="181"/>
        <source>Quit after background change</source>
        <translation>Termina dopo cambio sfondo</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="188"/>
        <source>Start automatically when system starts</source>
        <translation>Avvia all&apos;avvio del sistema</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="195"/>
        <source>Only use landscape-oriented photos</source>
        <translation>Usa solo foto panoramiche</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="202"/>
        <source>Rotate images according to EXIF information</source>
        <translation>Ruota le immagini secondo le informazioni EXIF</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="211"/>
        <source>View info on photo</source>
        <translation>Visualizza informazioni sulla foto</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="269"/>
        <source>View info in system tray tooltip</source>
        <translation>Visualizza informazioni sull&apos;icona</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="276"/>
        <source>Use full desktop area</source>
        <translation>Usa l&apos;intera area del desktop</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="285"/>
        <source>Photo has to be</source>
        <translation>La foto deve essere</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="296"/>
        <source>independent of</source>
        <translation>indipendente rispetto alle</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="301"/>
        <source>at least 1/2 of</source>
        <translation>almeno 1/2 delle</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="306"/>
        <source>at least 3/4 of</source>
        <translation>almeno 3/4 delle</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="311"/>
        <source>bigger than</source>
        <translation>più grande delle</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="319"/>
        <source>desktop&apos;s size</source>
        <translation>dimensioni del desktop</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="381"/>
        <source>Store images in history for</source>
        <translation>Memorizza immagini in cronologia per</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="398"/>
        <source>Clear</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="433"/>
        <source>Direct connection</source>
        <translation>Connessione diretta</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="443"/>
        <source>Proxy connection</source>
        <translation>Connessione tramite proxy</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="343"/>
        <source>Don&apos;t save locally remote photos if free disk space goes below</source>
        <translation>Non salvare localmente le foto remote se lo spazio libero é minore di</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="630"/>
        <source>Engines</source>
        <translation>Moduli</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="750"/>
        <source>Available modules:</source>
        <translation>Moduli disponibili:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="757"/>
        <source>Active modules:</source>
        <translation>Moduli attivi:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="421"/>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="467"/>
        <source>Use system proxy</source>
        <translation>Usa proxy di sistema</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="477"/>
        <source>Use custom proxy</source>
        <translation>Usa proxy manuale</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="497"/>
        <source>Port:</source>
        <translation>Porta:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="547"/>
        <source>Authentication</source>
        <translation>Autenticazione</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="562"/>
        <source>Username:</source>
        <translation>Nome utente:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="579"/>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="487"/>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="514"/>
        <source>Changes won&apos;t be applied. Are you sure?</source>
        <translation>Le modifiche non verranno applicate. Continuare?</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="239"/>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="240"/>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
</context>
<context>
    <name>SmugMug::DialogWidget</name>
    <message>
        <location filename="../../src/smugmug.cpp" line="252"/>
        <source>Search for:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <location filename="../../src/smugmug.cpp" line="275"/>
        <source>Edit SmugMug item</source>
        <translation>Edita oggetto Smugmug</translation>
    </message>
    <message>
        <location filename="../../src/smugmug.cpp" line="280"/>
        <source>Add SmugMug item</source>
        <translation>Aggiungi oggetto Smugmug</translation>
    </message>
</context>
<context>
    <name>SmugMug::Item</name>
    <message>
        <location filename="../../src/smugmug.cpp" line="47"/>
        <source>Text:</source>
        <translation>Testo:</translation>
    </message>
</context>
<context>
    <name>SplashScreen</name>
    <message>
        <location filename="../../src/splash.cpp" line="46"/>
        <source>Author:</source>
        <translation>Autore:</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="109"/>
        <source>Loading Files module ...</source>
        <translation>Carico modulo File ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="116"/>
        <source>Loading Folders module ...</source>
        <translation>Carico modulo Cartelle ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="123"/>
        <source>Loading Flickr module ...</source>
        <translation>Carico modulo Flickr ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="137"/>
        <source>Loading Panoramio module ...</source>
        <translation>Carico modulo Panoramio ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="151"/>
        <source>Loading Ipernity module ...</source>
        <translation>Carico modulo Ipernity ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="158"/>
        <source>Loading Photobucket module ...</source>
        <translation>Carico modulo Photobucket ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="165"/>
        <source>Loading Buzznet module ...</source>
        <translation>Carico modulo Buzznet ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="172"/>
        <source>Loading Picasa module ...</source>
        <translation>Carico modulo Picasa ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="179"/>
        <source>Loading SmugMug module ...</source>
        <translation>Carico modulo Smugmug ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="193"/>
        <source>Loading Google module ...</source>
        <translation>Carico modulo Google ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="200"/>
        <source>Loading Vladstudio module ...</source>
        <translation>Carico modulo Vladstudio ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="207"/>
        <source>Loading deviantART module ...</source>
        <translation>Carico modulo deviantART ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="214"/>
        <source>Loading settings ...</source>
        <translation>Carico impostazioni ...</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="221"/>
        <source>Launching Wally ...</source>
        <translation>Avvio Wally ...</translation>
    </message>
</context>
<context>
    <name>Viewer</name>
    <message>
        <location filename="../../ui/viewer.ui" line="9"/>
        <source>Right-click on photo to show actions</source>
        <translation>Click con il destro per mostrare le azioni</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="63"/>
        <source>Fit to window</source>
        <translation>Adatta alla finestra</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="72"/>
        <source>Show full image</source>
        <translation>Dimensioni reali</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="81"/>
        <source>Zoom in</source>
        <translation>Ingrandisci</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="90"/>
        <source>Zoom out</source>
        <translation>Riduci</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="99"/>
        <source>Rotate clockwise</source>
        <translation>Ruota in senso orario</translation>
    </message>
    <message>
        <location filename="../../ui/viewer.ui" line="108"/>
        <source>Rotate c. clockwise</source>
        <translation>Ruota in senso antiorario</translation>
    </message>
</context>
<context>
    <name>Vladstudio::DialogWidget</name>
    <message>
        <location filename="../../src/vladstudio.cpp" line="325"/>
        <source>All</source>
        <translation>Tutti</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="326"/>
        <source>Abstract art</source>
        <translation>Arte astratta</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="327"/>
        <source>Creatures</source>
        <translation>Creature</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="328"/>
        <source>Illustrations</source>
        <translation>Illustrazioni</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="329"/>
        <source>Photos</source>
        <translation>Foto</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="334"/>
        <source>By ID</source>
        <translation>Per ID</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="335"/>
        <source>By view count</source>
        <translation>Per visualizzazioni</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="340"/>
        <source>Ascending</source>
        <translation>Ascendente</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="341"/>
        <source>Descending</source>
        <translation>Discendente</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="344"/>
        <source>Category:</source>
        <translation>Categoria:</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="345"/>
        <source>Order:</source>
        <translation>Ordine:</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="346"/>
        <source>Direction:</source>
        <translation>Direzione:</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="368"/>
        <source>Edit Vladstudio item</source>
        <translation>Edita oggetto Vladstudio</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="375"/>
        <source>Add Vladstudio item</source>
        <translation>Aggiungi oggetto Vladstudio</translation>
    </message>
</context>
<context>
    <name>Vladstudio::Item</name>
    <message>
        <location filename="../../src/vladstudio.cpp" line="42"/>
        <source>All categories</source>
        <translation>Tutte le categorie</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="46"/>
        <source>Abstract art</source>
        <translation>Arte astratta</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="50"/>
        <source>Creatures</source>
        <translation>Creature</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="54"/>
        <source>Illustrations</source>
        <translation>Illustrazioni</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="58"/>
        <source>Photos</source>
        <translation>Foto</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="89"/>
        <source>by Id</source>
        <translation>per Id</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="93"/>
        <source>by view count</source>
        <translation>per visualizzazioni</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="105"/>
        <source>ascending</source>
        <translation>ascendente</translation>
    </message>
    <message>
        <location filename="../../src/vladstudio.cpp" line="109"/>
        <source>descending</source>
        <translation>discendente</translation>
    </message>
</context>
<context>
    <name>Wally::Application</name>
    <message>
        <location filename="../../src/wally.cpp" line="621"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="623"/>
        <location filename="../../src/wally.cpp" line="2114"/>
        <source>Play</source>
        <translation>Riproduci</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="625"/>
        <location filename="../../src/wally.cpp" line="2094"/>
        <source>Pause</source>
        <translation>Interrompi</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="626"/>
        <source>Next photo</source>
        <translation>Prossima foto</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="627"/>
        <source>Save photo...</source>
        <translation>Salva foto...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="628"/>
        <source>Get EXIF info...</source>
        <translation>Mostra informazioni EXIF...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="629"/>
        <source>Settings...</source>
        <translation>Impostazioni...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="630"/>
        <source>Explore source</source>
        <translation>Esplora sorgente</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="631"/>
        <source>About...</source>
        <translation>Informazioni su...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="632"/>
        <source>History...</source>
        <translation>Cronologia...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="633"/>
        <source>About Qt...</source>
        <translation>Informazioni su Qt...</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="634"/>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="637"/>
        <source>English</source>
        <translation>Inglese</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="638"/>
        <source>Italian</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="639"/>
        <source>Spanish</source>
        <translation>Spagnolo</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="640"/>
        <source>German</source>
        <translation>Tedesco</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="641"/>
        <source>French</source>
        <translation>Francese</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="642"/>
        <source>Russian</source>
        <translation>Russo</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="644"/>
        <source>Czech</source>
        <translation>Ceco</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="645"/>
        <source>Polish</source>
        <translation>Polacco</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="635"/>
        <source>Languages</source>
        <translation>Lingue</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="646"/>
        <source>Chinese (Simplified)</source>
        <translation>Cinese (Semplificato)</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="647"/>
        <source>Chinese (Traditional)</source>
        <translation>Cinese (Tradizionale)</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="648"/>
        <source>Catalan</source>
        <translation>Catalano</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="649"/>
        <source>Greek</source>
        <translation>Greco</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="650"/>
        <source>Korean</source>
        <translation>Coreano</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="651"/>
        <source>Hungarian</source>
        <translation>Ungherese</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="652"/>
        <source>Danish</source>
        <translation>Danese</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="653"/>
        <source>Swedish</source>
        <translation>Svedese</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="654"/>
        <source>Turkish</source>
        <translation>Turco</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="1685"/>
        <source>Wally Error</source>
        <translation>Errore Wally</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="1685"/>
        <source>Active Desktop must be disabled</source>
        <translation>Active Desktop deve essere disabilitato</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="1774"/>
        <location filename="../../src/wally.cpp" line="2065"/>
        <source>by:</source>
        <translation>da:</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="1783"/>
        <source>Location:</source>
        <translation>Luogo:</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="1791"/>
        <location filename="../../src/wally.cpp" line="2070"/>
        <source>Engine:</source>
        <translation>Modulo:</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="2154"/>
        <location filename="../../src/wally.cpp" line="2157"/>
        <source>Save photo</source>
        <translation>Salva foto</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="2155"/>
        <location filename="../../src/wally.cpp" line="2159"/>
        <source>Images (*.png *.xpm *.jpg)</source>
        <translation>Immagini (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="2654"/>
        <source>Right-click to show main menu</source>
        <translation>Click con il destro per mostrare menù principale</translation>
    </message>
    <message>
        <location filename="../../src/wally.cpp" line="643"/>
        <source>Portuguese (Brazil)</source>
        <translation>Portoghese (Brasile)</translation>
    </message>
</context>
<context>
    <name>Yahoo::DialogWidget</name>
    <message>
        <location filename="../../src/yahoo.cpp" line="268"/>
        <source>All of these words</source>
        <translation>Tutte le parole</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="269"/>
        <source>Any of these words</source>
        <translation>Una di queste parole</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="272"/>
        <source>Search for:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="277"/>
        <source>Filter content</source>
        <translation>Filtra contenuto</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="297"/>
        <source>Yahoo! item</source>
        <translation>Oggetto Yahoo!</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="298"/>
        <source>Unfiltered content can show offending or sexual explicit photos</source>
        <translation>Il contenuto non filtrato potrà mostrare contenuto offensivo o sessualmente esplicito</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="309"/>
        <source>Edit Yahoo! item</source>
        <translation>Edita oggetto Yahoo!</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="317"/>
        <source>Add Yahoo! item</source>
        <translation>Aggiungi oggetto Yahoo!</translation>
    </message>
</context>
<context>
    <name>Yahoo::Item</name>
    <message>
        <location filename="../../src/yahoo.cpp" line="56"/>
        <source>Tags:</source>
        <translation>Tag:</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="58"/>
        <source>and</source>
        <translation>e</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="58"/>
        <source>or</source>
        <translation>o</translation>
    </message>
    <message>
        <location filename="../../src/yahoo.cpp" line="61"/>
        <source>content filtered</source>
        <translation>contenuto filtrato</translation>
    </message>
</context>
</TS>
